% Voiced/unvoiced detection with energy and zero crossings (a very
% simplistic approach, hand tuned to a specific recording)

clear
close all
clc

%% Read data containing WAV and EGG signal (from ARCTIC)
%  (first channel contains sound, second channel contains EGG)
[data fs] = wavread('bdl_arctic_a0013.wav');
x   = resample(data(:,1), 1,2);
egg = resample(data(:,2), 1,2);
fs  = fs/2;
% soundsc(x,fs);

%% Estimate energy and zero crossings
wlen  = round(30e-3*fs);
wshft = round(1e-3*fs);
nfft  = 1024;

[voiced rms zc] = vuv(x,fs,wlen,wshft);

% Resample the voiced detector to match fs
voiced_fs = resample(voiced, length(x), length(voiced));


%% Plotting results
figure
subplot(311); 
plot(x.*voiced_fs'); axis tight
hold on
plot(x.*(1-voiced_fs)', 'r'); axis tight

subplot(312); 
spectrogram(x,wlen,wlen-wshft,nfft,fs,'yaxis'); 

subplot(313); 
plot(rms/max(rms), 'r');
hold on
plot(zc/max(zc), 'g'); 
plot(find(voiced), 0, 'b.');
legend('rms', 'zc', 'voiced'); axis tight; box on; 